package net.sf.javaprinciples.data.transformer;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

/**
 * A holder of differences.
 *
 * @author Warwick Slade
 */
public class DiffResult implements Serializable
{
    private boolean different;
    private Map<String, Difference> fields;

    public enum Difference
    {
        BOTH_NULL,
        LEFT_NULL,
        RIGHT_NULL,
        SAME,
        DIFFERENT
    }

    public DiffResult(String field, Difference difference)
    {
        fields = new HashMap<String, Difference>();
        fields.put(field, difference);
        different = difference != Difference.SAME && difference != Difference.BOTH_NULL;
    }

    public boolean isDifferent()
    {
        return different;
    }

    public Set<String> getFields()
    {
        return fields.keySet();
    }

    public Difference getDifference(String field)
    {
        return fields.get(field);
    }

    public String toString()
    {
        return isDifferent() ? "Different" : "Same";
    }

    public void add(DiffResult e)
    {
        fields.putAll(e.fields);
        if (!different)
        {
            different = e.isDifferent();
        }
    }
}
